# This package is for specifications of flow components that are used ONLY as flow component specifications. If there
# is a job specification relating to a certain flow component, e.g. ImportFileSpecification, that is used as the
# component specification as well, and there will not be a separate specification class here.
